
************
Installation
************

The package can be installed using `pip <https://pypi.python.org/pypi/pip>`_

.. code-block:: bash

   pip install mendeleev

You can also install the most recent version from the repository:

.. code-block:: bash

   pip install https://bitbucket.org/lukaszmentel/mendeleev/get/tip.tar.gz

If you use `conda <https://conda.io/docs/intro.html>`_ you can install 
the package from `my anaconda channel <https://anaconda.org/lmmentel/mendeleev>`_ by 

.. code-block:: bash

   conda install -c lmmentel mendeleev=0.4.1
